@@ -467,7 +467,6 @@ class Screen:
     def remove(self, obj):
         if obj in self._objects:
             self._objects.remove(obj);
-            print('removed: ' + str(type(obj)));
         elif obj not in self._gridlines and obj not in self._helpers:
             raise ValueError(f'Object: {obj} is not registered with the screen? Did you call the constructor?');
         self._screen.cv.delete(obj._ref);
@@ -490,7 +489,6 @@ class Screen:
         try:
             for i in range(len(self._objects) - 1, -1, -1):
                 self._objects[i].remove();
-            # self._screen.clear();
             if self._gridstate:
                 self._redraw_grid();  # Redraw the grid if it was active.
             self.color(self._color);  # Redraw the color of the screen.
